@@ -30,7 +30,7 @@
     colnames(y) <- ylab
     rownames(y) <- x
     return(structure(list(x = x, y = y, time = ytimes, xname = xname, 
-        yname = yname), class = c("fts","fd")))
+        yname = yname), class = c("fts","fds")))
 
 }
 
